@@ -485,6 +485,17 @@ class Transaction(models.Model):
     funds.
     """
 
+    amount_expected = models.DecimalField(
+        null=True, blank=True, max_digits=30, decimal_places=7
+    )
+    """
+    Amount the client specified would be sent to the anchor at the start of
+    a transaction. Note that ``Transaction.amount_in`` can differ from this field 
+    after funds have been received. Until then, the fields will match. This field
+    makes it possible to check if the amount sent to the anchor matches the amount
+    the client initially specified in an API request or form.
+    """
+
     amount_out = models.DecimalField(
         null=True, blank=True, max_digits=30, decimal_places=7
     )
@@ -573,7 +584,7 @@ class Transaction(models.Model):
     channel_seed = EncryptedTextField(null=True, blank=True)
     """
     A keypair of the account used when sending SEP-6 or SEP-24 deposit 
-    transactions to Transaction.stellar_account, if present. 
+    transactions to Transaction.to_address, if present. 
     This is only used for transactions requiring signatures Polaris cannot
     add itself.
     """
